
package de.codedo.conflicteditor.gui.util;

import de.codedo.conflicteditor.gui.ConflictEditor;

import java.text.DecimalFormat;
import java.util.Arrays;
import java.util.Vector;
import java.util.prefs.BackingStoreException;
import java.util.prefs.Preferences;

public class PreferencesAccess extends Object
{
    private Preferences _rootNode;

    public PreferencesAccess()
    {
        super();
        _rootNode = Preferences.userNodeForPackage(ConflictEditor.class);
    }

    public Vector<String> getDatabaseUrls()
    {
        try
        {
            return collectDatabaseUrls();
        }
        catch (BackingStoreException bse)
        {
            throw new IllegalStateException(bse);
        }
    }

    private Vector<String> collectDatabaseUrls() throws BackingStoreException
    {
        Vector<String> urls = new Vector<String>();
        Preferences databaseUrls = databaseUrlsNode();
        for (String key : databaseUrls.keys())
        {
            String url = databaseUrls.get(key, null);
            urls.add(url);
        }
        return urls;
    }

    public void storeDatabaseUrl(String url)
    {
        try
        {
            if (isDatabaseUrlStored(url) == false)
            {
                storeUrl(url);
            }
        }
        catch (BackingStoreException bse)
        {
            throw new IllegalStateException(bse);
        }
    }

    private boolean isDatabaseUrlStored(String url) throws BackingStoreException
    {
        Preferences databaseUrls = databaseUrlsNode();
        for (String key : databaseUrls.keys())
        {
            String storedUrl = databaseUrls.get(key, null);
            if (storedUrl.equals(url))
            {
                return true;
            }
        }
        return false;
    }

    private void storeUrl(String url) throws BackingStoreException
    {
        Preferences databaseUrls = databaseUrlsNode();
        String key = keyForStoringDatabaseUrl();
        databaseUrls.put(key, url);
        databaseUrls.flush();
    }

    private String keyForStoringDatabaseUrl() throws BackingStoreException
    {
        Preferences databaseUrls = databaseUrlsNode();
        String[] keys = databaseUrls.keys();
        Arrays.sort(keys);

        int lastKey = Integer.valueOf(keys[keys.length - 1]).intValue();
        int nextKey = lastKey + 1;
        return new DecimalFormat("00").format(nextKey);
    }

    private Preferences databaseUrlsNode()
    {
        return _rootNode.node("databaseUrls");
    }
}
