
package de.codedo.conflicteditor;

import static org.hamcrest.CoreMatchers.equalTo;
import static org.hamcrest.CoreMatchers.is;
import static org.hamcrest.CoreMatchers.not;
import static org.hamcrest.MatcherAssert.assertThat;

import org.junit.Test;

public class DifferenceTestCase extends Object
{
    @Test
    public void differencesWithSameValuesShouldBeEqual()
    {
        Difference diff1 = new Difference("key", "current", "other");
        Difference diff2 = new Difference("key", "current", "other");
        assertThat(diff1, equalTo(diff2));
    }

    @Test
    public void differencesWithDifferentValuesShouldNotBeEqual()
    {
        Difference diff1 = new Difference("key", "current", "other");
        Difference diff2 = new Difference("other-key", "current", "other");
        assertThat(diff1, not(equalTo(diff2)));
    }

    @Test
    public void valuesSholdBeQuoted()
    {
        Difference diff = new Difference("key", "theValue", null);
        assertThat(diff.toString(), is("key : \"theValue\" - null"));
    }

    @Test
    public void valueWithoutLeadingQuoteShouldBeFormattedSurroundedByQuotes()
    {
        Difference diff = new Difference("key", "theValue\"", null);
        assertThat(diff.toString(), is("key : \"theValue\" - null"));
    }

    @Test
    public void valueWithoutTrailingQuoteShouldBeFormattedSurroundedByQuotes()
    {
        Difference diff = new Difference("key", "\"theValue", null);
        assertThat(diff.toString(), is("key : \"theValue\" - null"));
    }

    @Test
    public void nullValuesShouldBeFormattedWithoutSurroundingQuotes()
    {
        Difference diff = new Difference("key", null, null);
        assertThat(diff.toString(), is("key : null - null"));
    }
}
